<?php
/**
 * Retrieves and creates the wp-config.php file.
 *
 * The permissions for the base directory must allow for writing files in order
 * for the wp-config.php to be created using this page.
 *
 * @package WordPress
 * @subpackage Administration
 */

/**
 * We are installing.
 *
 * @package WordPress
 */
define('WP_INSTALLING', true);

/**#@+
 * These three defines are required to allow us to use require_wp_db() to load
 * the database class while being wp-content/db.php aware.
 * @ignore
 */
define('ABSPATH', dirname(dirname(__FILE__)).'/');
define('WPINC', 'wp-includes');
define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
/**#@-*/

require_once('../wp-includes/compat.php');
require_once('../wp-includes/functions.php');
require_once('../wp-includes/classes.php');

if (!file_exists('../wp-config-sample.php'))
	wp_die('Maaf, saya perlukan fail wp-config-sample.php untuk dijadikan contoh. Sila muat naik semula fail ini daripada pemasangan WordPress anda.');

$configFile = file('../wp-config-sample.php');

if ( !is_writable('../'))
	wp_die("Maaf, saya tak dapat menulis ke dalam direktori ini. Ada perlu mengubah keizinan bagi direktori WordPress atau mencipta fail wp-config.php secara manual.");

// Check if wp-config.php has been created
if (file_exists('../wp-config.php'))
	wp_die("<p>Fail 'wp-config.php' telah pun wujud. Jika anda mahu set semula mana-mana item konfigurasi dalam fail ini, sila hapuskannya terlebih dahulu. Sekarang anda boleh <a href='install.php'>memasang WordPress</a>.</p>");

// Check if wp-config.php exists above the root directory
if (file_exists('../../wp-config.php') && ! file_exists('../../wp-load.php'))
	wp_die("<p>Fail 'wp-config.php' telah pun wujud satu aras di atas direktori WordPress anda. Sekiranya anda mahu menetapkan semula mana-mana item konfigurasi dalam fail ini, sila hapuskannya terlebih dahulu. Sekarang anda boleh <a href='install.php'>memasang WordPress</a>.</p>");

if (isset($_GET['step']))
	$step = $_GET['step'];
else
	$step = 0;

/**
 * Display setup wp-config.php file header.
 *
 * @ignore
 * @since 2.3.0
 * @package WordPress
 * @subpackage Installer_WP_Config
 */
function display_header(){
	header( 'Content-Type: text/html; charset=utf-8' );
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>WordPress &rsaquo; Persediaan Fail Konfigurasi</title>
<link rel="stylesheet" href="css/install.css" type="text/css" />

</head>
<body>
<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
<?php
}//end function display_header();

switch($step) {
	case 0:
		display_header();
?>

<p>Selamat datang ke WordPress. Sebelum bermula, kita perlukan beberapa maklumat mengenai pangkalan data. Anda perlu mengetahui perkara-perkara berikut sebelum meneruskan.</p>
<ol>
	<li>Nama pangkalan data</li>
	<li>Nama pengguna pangkalan data</li>
	<li>Kata laluan pangkalan data</li>
	<li>Hos pangkalan data</li>
	<li>Awalan jadual (sekiranya anda mahu menjalankan lebih daripada sebuah pemasangan WordPress menggunakan pangkalan data yang sama)</li>
</ol>
<p><strong>Andai kata penciptaan fail automatik ini tidak berfungsi, usah bimbang. Skrip ini cuma mengisikan maklumat pangkalan data ke dalam sebuah fail konfigurasi. Anda boleh membuka <code>wp-config-sample.php</code> dengan menggunakan sebuah penyunting teks, kemudian isikan maklumat anda, dan simpannya dengan nama <code>wp-config.php</code>.</strong></p>
<p>Besar kemungkinan item-item ini telah dibekalkan oleh hos web anda. Jika anda tidak mempunyai maklumat ini, maka anda perlu menghubungi mereka sebelum anda boleh meneruskan. Jika semua sudah tersedia&hellip;</p>

<p class="step"><a href="setup-config.php?step=1" class="button">Mari kita bermula!</a></p>
<?php
	break;

	case 1:
		display_header();
	?>
<form method="post" action="setup-config.php?step=2">
	<p>Anda perlu memasukkan butir-butir bagi sambungan pangkalan data anda. Jika anda tidak pasti mengenai perkara ini, sila hubungi hos anda.</p>
	<table class="form-table">
		<tr>
			<th scope="row"><label for="dbname">Nama Pangkalan Data</label></th>
			<td><input name="dbname" id="dbname" type="text" size="25" value="wordpress" /></td>
			<td>Nama pangkalan data yang bakal digunakan oleh WP.</td>
		</tr>
		<tr>
			<th scope="row"><label for="uname">Nama Pengguna</label></th>
			<td><input name="uname" id="uname" type="text" size="25" value="username" /></td>
			<td>Nama pengguna MySQL</td>
		</tr>
		<tr>
			<th scope="row"><label for="pwd">Kata Laluan</label></th>
			<td><input name="pwd" id="pwd" type="text" size="25" value="password" /></td>
			<td>...dan kata laluan MySQL anda.</td>
		</tr>
		<tr>
			<th scope="row"><label for="dbhost">Hos Pangkalan Data</label></th>
			<td><input name="dbhost" id="dbhost" type="text" size="25" value="localhost" /></td>
			<td>99% kemungkinan anda tidak perlu mengubah nilai ini.</td>
		</tr>
		<tr>
			<th scope="row"><label for="prefix">Awalan Jadual</label></th>
			<td><input name="prefix" id="prefix" type="text" id="prefix" value="wp_" size="25" /></td>
			<td>Sekiranya anda mahu menjalankan beberapa pemasangan WordPress dalam pangkalan data yang sama, sila ubah nilai ini.</td>
		</tr>
	</table>
	<p class="step"><input name="submit" type="submit" value="Serah" class="button" /></p>
</form>
<?php
	break;

	case 2:
	$dbname  = trim($_POST['dbname']);
	$uname   = trim($_POST['uname']);
	$passwrd = trim($_POST['pwd']);
	$dbhost  = trim($_POST['dbhost']);
	$prefix  = trim($_POST['prefix']);
	if (empty($prefix)) $prefix = 'wp_';

	// Test the db connection.
	/**#@+
	 * @ignore
	 */
	define('DB_NAME', $dbname);
	define('DB_USER', $uname);
	define('DB_PASSWORD', $passwrd);
	define('DB_HOST', $dbhost);
	/**#@-*/

	// We'll fail here if the values are no good.
	require_wp_db();
	if ( !empty($wpdb->error) )
		wp_die($wpdb->error->get_error_message());

	$handle = fopen('../wp-config.php', 'w');

	foreach ($configFile as $line_num => $line) {
		switch (substr($line,0,16)) {
			case "define('DB_NAME'":
				fwrite($handle, str_replace("putyourdbnamehere", $dbname, $line));
				break;
			case "define('DB_USER'":
				fwrite($handle, str_replace("'usernamehere'", "'$uname'", $line));
				break;
			case "define('DB_PASSW":
				fwrite($handle, str_replace("'yourpasswordhere'", "'$passwrd'", $line));
				break;
			case "define('DB_HOST'":
				fwrite($handle, str_replace("localhost", $dbhost, $line));
				break;
			case '$table_prefix  =':
				fwrite($handle, str_replace('wp_', $prefix, $line));
				break;
			default:
				fwrite($handle, $line);
		}
	}
	fclose($handle);
	chmod('../wp-config.php', 0666);
	
	display_header();
?>
<p>Baiklah! Anda telah berjaya melalui proses pemasangan pada bahagian ini. Sekarang WordPress boleh berkomunikasi dengan pangkalan data anda. Jika anda sudah bersedia, tibalah masanya untuk&hellip;</p>

<p class="step"><a href="install.php" class="button">Pasang WordPress</a></p>
<?php
	break;
}
?>
</body>
</html>
